@@ -4,7 +4,7 @@ use std::string::ToString;
 use v_common::module::remote_indv_r_storage::get_individual;
 use v_common::module::veda_backend::indv_apply_cmd;
 use v_common::onto::individual::Individual;
-use v_common::onto::onto::Onto;
+use v_common::onto::onto_impl::Onto;
 use v_common::onto::parser::parse_raw;
 use v_common::v_api::api_client::{IndvOp, MStorageClient, ALL_MODULES};
 use v_common::v_api::obj::ResultCode;
